GOOF----LE-4-2.0#5      ] ^ 4        h>      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
g  api	
 	 	
						
		 	g  tableau					 	g  
foundation	g  initialize-playing-area	g  set-ace-low	g  make-standard-deck	g  shuffle-deck	g  add-normal-slot	g  DECK	g  stock	g  waste	g  add-blank-slot	g  add-carriage-return-slot	g  add-extended-slot	g  down	g  
deal-cards							
							
						
					
			
					 	g  map	 g  
flip-top-card	!g  give-status-message	"g  new-game	#g  set-statusbar-message	$g  
string-append	%g  get-stock-no-string	&f     	'g  get-redeals-string	(g  _	)f  Stock left:	*f   	+g  number->string	,g  length	-g  	get-cards	.f  
Redeals left:	/g  FLIP-COUNTER	0g  is-visible?	1g  reverse	2g  button-pressed	3g  
move-n-cards!	4g  member	5g  
add-to-score!	6g  empty-slot?	7g  make-visible-top-card	8g  complete-transaction	9g  get-suit	:g  get-top-card	;g  	get-value	<g  ace	=g  
droppable?	>g  button-released	?g  
flip-stock	@g  button-clicked	Ag  remove-card	Bg  button-double-clicked	Cg  do-deal-next-cards	Dg  
flippable?	Eg  	dealable?	Fg  get-hint	Gg  game-continuable	Hg  game-won	Ig  empty-exist?	Jg  	hint-move	Kg  find-empty-slot	Lg  check-waste-to-empty	Mg  stripped-len	Ng  check-tableau-to-empty	Og  check-empty?	Pg  check-a-foundation	Qg  check-to-foundations	Rg  
check-a-tslot	Sg  check-tslot	Tg  check-to-tableau	Uf  Deal another round	Vf  Move waste back to stock	Wg  get-options	Xg  
apply-options	Yg  timeout	Zg  set-features	[g  droppable-feature	\g  dealable-feature	]g  
set-lambdaC 5     h+  i  ] 4	 >  "  G  
RR ! h    ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>  "  G  4	>   "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4>   "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4
>  "  G  4>  "  G  4>   "  G  		 C {      g  filenamef  thumb-and-pouch.scm
	
							#			3			C			I			N			W			Z			\			a			j	 		z	!		}	!			!	 	!	 	"	 	"	 	"	 	"	 	#	 	#	 	#	 	#	 	$	 	$	 	$	 	$	 	%	 	&	 	&	 	&	 	&	 	'	 	'	 	'	 	'	 	(		(		(		(		)		)		)	!	)	*	*	-	*	1	*	6	*	?	+	B	+	F	+	K	+	T	,	W	,	[	,	`	,	i	.	n	.	s	.	|	0		2		4	 A	
  g  nameg  new-game C"R#$%&'    h      ] 445 45 56        g  filenamef  thumb-and-pouch.scm
	6
		7			7	(		8	(		9	(		7			7	 		
  g  nameg  give-status-message C!R$()*+,-      h       ] 45444
5556        g  filenamef  thumb-and-pouch.scm
	;
		<				<			<		
	<	"		=			=	!		=	)		=	!		=			<	 		
  g  nameg  get-stock-no-string C%R$(.*+/        h       ] 454	56              g  filenamef  thumb-and-pouch.scm
	?
		@				@			@		
	@	$		A			A	!		A			@	 
		
  g  nameg  get-redeals-string C'R,01       h@      ]
 $  "   $  
45"  $  456C         g  slot-id
		> g  	card-list		> g  t			,  g  filenamef  thumb-and-pouch.scm
	C
		D			D			E			E			F		$	F		0	D		3	G		:	G		<	G	 		>	  g  nameg  button-pressed C2R34567       h     ]4 >  "  G  4 5$  4	>  "  G  "   45$  4>  "  G  "   4 5$  "  	4 5$  4 >  "  G  "   C            g  
start-slot
	  g  	card-list	  g  end-slot		   g  filenamef  thumb-and-pouch.scm
	I
		J			K		%	K		&	L		<	M		H	M		I	N		^	O		h	O		n	P		z	O		{	Q	 	 	  g  nameg  complete-transaction C8R469:1;,<     h    ] $  C45$  Y45$  "  =44554455&  "  44554455"  $  C45$  s4	5$  d45$  
45"  $  C45$  C445545&  445545CCCC             g  
start-slot
	 g  	card-list	 g  end-slot		 g  t		!	o g  t		t g  t	    g  filenamef  thumb-and-pouch.scm
	T
		U			U			V			V			W		!	W		0	X	#	3	X	-	;	X	#	<	Y	#	?	Y	2	F	Y	-	H	Y	#	L	X		R	Z		U	Z	'	]	Z		^	[	!	a	[	1	h	[	,	j	[	!	k	[		l	Z		t	V	 	\	 	\	 	]	 	]	 	\	 	^	 	^	 	_	  	_	+ 	_	  	_	 	^	 	`	 	`	 	a	 	a	( 	a	 	b	 	b	( 	b	 	`	 	c	 	c	' 	c	 	d	 	d	* 	d	 	d	 	c	 7		  g  nameg  
droppable? C=R=8  h       ]4 5$  
 6C          g  
start-slot
		 g  	card-list		 g  end-slot			  g  filenamef  thumb-and-pouch.scm
	f
		g			g			h	 			  g  nameg  button-released C>R?!      h       ] 
$  4
	5$  6 CC        g  slot-id
		  g  filenamef  thumb-and-pouch.scm
	j
		k		
	k			l			k			m	 		  g  nameg  button-clicked C@R46:9;<A8 
hX    ])4 5$  "   $ ,4 5$  C4 545454	5$  	"  44	55$  	"  4	5$  	"  44	55$  	"  [4	5$  	"  44	55$  	"  .4	5$  	"  44	55$  	"  $  E$  "  4455$  4 5$  
	  6CCCC             g  slot-id
	Q g  t		 g  card	7O g  suit		@O g  value		IO g  end-slot	 O g  t	
-  g  filenamef  thumb-and-pouch.scm
	o
		p			p			q		#	p		$	r		.	p		1	s		7	s		:	t		@	s		C	u		I	s		L	w		V	w		[	x		b	y	#	e	y	-	m	y	#	n	y		r	w		y	z	 	z	 	{	 	|	# 	|	- 	|	# 	|	 	w	 	}	 	}	 	~	 		# 		- 		# 		 	w	  	  	  	  	#  	-  	#  	 	w	 	v		 	
 	
 	 	 	"& 	) 	;* 	1 	2 	< 	E 	.I 	 <	Q  g  nameg  button-double-clicked CBR?!     h    w   ] 4
	>  "  G  6       o       g  filenamef  thumb-and-pouch.scm
 
	 		 	 		
  g  nameg  do-deal-next-cards CCRD        h   e   ] 
	6      ]       g  filenamef  thumb-and-pouch.scm
 
	
 	 		

  g  nameg  	dealable? CERF  h   l   ] 6   d       g  filenamef  thumb-and-pouch.scm
 
	 	 		
  g  nameg  game-continuable CGR,- hX     ] 	
44	55$  :	
44	55$  %	
44	55$  	
44	55CCCC              g  filenamef  thumb-and-pouch.scm
 
	 	
	 		 	
	 		 		 	
	 		# 	
	$ 		( 		+ 	
	. 		6 	
	7 		; 		> 	
	A 		I 	
	J 	 		Q
  g  nameg  game-won CHR6I       h(      ] 	
$  C4 5$  C 6              g  slot-id
		!  g  filenamef  thumb-and-pouch.scm
 
	 			 		 			 		 		! 		 		!  g  nameg  empty-exist? CIR6JK      h       ] 45$  C456            g  filenamef  thumb-and-pouch.scm
 
	 		 		 		 	 		
  g  nameg  check-waste-to-empty CLR0M  h       ]4 5$  
 6C           g  	card-list
		 g  acc		  g  filenamef  thumb-and-pouch.scm
 
	 		 		 		 		 		 	$	 	 				  g  nameg  stripped-len CMR601-JMKN 
       hX   *  ] 	
$  C4 5$  "  444 555$   44 55456	 6   "      g  slot-id
		U  g  filenamef  thumb-and-pouch.scm
 
	 			 		 		 			 		! 	%	$ 	.	, 	%	- 	 	/ 		0 		4 		9 		< 	*	E 		F 	A	N 			S 	$	U 	 		U  g  nameg  check-tableau-to-empty CNRINL h(      ]4	5$  4	5  $   C6 C          g  t
		#  g  filenamef  thumb-and-pouch.scm
 
	 		
 		 		 		# 	 		%
  g  nameg  check-empty? COR69:;JP<       h     ]	$  "   
$  "  4 5$  C"  c45$  "  1445545&  454455"  $   
$  C 6 645$  %45$   
$  C 6"m"i           g  slot-id
	  g  card	  g  f-slot		  g  t			2 g  t			/  g  filenamef  thumb-and-pouch.scm
 
	 	
	 			 		 	
	& 		6 		= 		G 			M 		P 		X 		Y 		c 			d 		k 		n 	!	v 		w 		x 	  	  	
  		  	
  	*  		  	  	  	  	  	  		  	
  		  	
 $	 	  g  nameg  check-a-foundation CPRQP:       h@      ]	 	$  C 	$  	64 4 5	5$  C 6         g  slot-id
		> g  t	,	>  g  filenamef  thumb-and-pouch.scm
 
	 			 		 			 		 			 	
	" 	)	, 	
	, 			< 	#	> 	
 
		>  g  nameg  check-to-foundations CQR,0;9PJR     h     ]45
$  "  )45$  "  4545$  C4545$  p4545&  "  T45$  "  '45$  "  
4		5$  4 5"  "  $  C 6           g  	from-slot
	  g  to-slot	  g  	num-cards		  g  card		  g  	card-list		  g  t			D g  t		!	A g  t	   g  t	   g  t	    
g  filenamef  thumb-and-pouch.scm
 
	 		 		 		 		 	"	  		! 		! 		/ 		4 		6 		7 	0	> 		H 		K 		R 		W 	#	Y 		Z 		[ 		_ 		` 		g 		l 	$	n 		r 		x 	  	  	  	  	&  	  	  	  	  	+  	  	  	  	  	,  	A  	 -	 	  g  nameg  
check-a-tslot CRRS6R:-        h     ]
	$  C	$   	64 5$  	 6$  .45$  "  4 4 545 5"  $  C4 4 5455$  C 6      g  to-slot
	  g  	from-slot	  g  t		i  g  t	    g  filenamef  thumb-and-pouch.scm
 
	 			 		 			 		 			 			) 		0 		2 			6 		: 	
	; 		D 	
	J 		R 	!	Y 	'	b 	!	d 		i 			u 	
	} 	  	  	
  		  	"  	
 	 	  g  nameg  check-tslot CSRST       h(      ]	 	$  C4 5$  C 6        g  slot-id
		' g  t		'  g  filenamef  thumb-and-pouch.scm
 
	 		 		 		 		% 		' 	 		'  g  nameg  check-to-tableau CTRQTO6(U/V 	   h   R  ]45  $   C4	5  $   C45   $   C4
5$  "  
45   $   C45$  C	$  
45 CC   J      g  t
		} g  t
		} g  t
	*	} g  t
	O	}  g  filenamef  thumb-and-pouch.scm
 
	 		 		 		 		& 		* 		6 		? 	
	F		J		L		O		O 		[		d	
	k		o	
	q		u		w		z	 		}
  g  nameg  get-hint CFR h   ^   ] C    V       g  filenamef  thumb-and-pouch.scm

 		
  g  nameg  get-options CWR     h   v   ]C    n       g  options
		  g  filenamef  thumb-and-pouch.scm
	
 		  g  nameg  
apply-options CXR     h   Z   ] C    R       g  filenamef  thumb-and-pouch.scm

 		
  g  nameg  timeout CYR4Zi[i\i>  "  G  ]i"i2i>i@iBiGiHiFiWiXiYi=iEi6
       a      g  filenamef  thumb-and-pouch.scm		
					
	 			#	
	
P	6
H	;
/	?
w	C

C	I
	T
	f
	j
K	o
 
 
 
 
n 
6 
2 
 
 
 
! 
$ 
') 
(( 
* 
*
+!	
+
+
+
 $	+
   C6 